@@ -49,7 +49,8 @@ def make_node(
 
     input_tensor = tf_layers_dict[graph_node_input.name]['tf_node'] \
         if isinstance(graph_node_input, gs.Variable) else graph_node_input
-    input_tensor_shape = tf.shape(input_tensor)
+    input_tensor_shape = input_tensor.shape
+    input_tensor_rank = len(input_tensor_shape)
 
     shape = graph_node_output.shape
     dtype = graph_node_output.dtype
@@ -80,6 +81,13 @@ def make_node(
     cal_shape = None
     if axis == 0:
         cal_shape = (1, -1)
+    elif len(graph_node_output.shape) == 2 and axis == input_tensor_rank - 1:
+        cal_shape = (1, -1)
+    elif input_tensor_rank >= 2 \
+        and input_tensor_shape[0] is None \
+        and len([idx for idx in input_tensor_shape[1:] if idx is not None]) == input_tensor_rank - 1 \
+        and axis == 1:
+        cal_shape = (-1, np.prod(input_tensor_shape[1:]))
     else:
         cal_shape = (
             tf.reduce_prod(input_tensor_shape[0:axis]),
@@ -102,6 +110,18 @@ def make_node(
         **kwargs,
     )
 
+    perm = [
+        convert_axis(
+            axis=idx,
+            tensor_rank=input_tensor_rank,
+            before_op_output_shape_trans=before_op_output_shape_trans,
+        ) for idx in range(input_tensor_rank)
+    ]
+    input_tensor = tf.transpose(
+        a=input_tensor,
+        perm=list(perm) if perm is not None else None,
+    )
+
     tf_layers_dict[graph_node_output.name]['tf_node'] = \
         tf.reshape(
             tensor=input_tensor,
