@@ -6,15 +6,19 @@ np.random.seed(0)
 import tensorflow as tf
 import onnx_graphsurgeon as gs
 from onnx2tf.utils.common_functions import (
+    get_replacement_parameter,
     get_constant_or_variable,
     convert_axis,
     print_node_info,
     inverted_operation_enable_disable,
     make_tf_node_info,
+    pre_process_transpose,
+    post_process_transpose,
 )
 
 @print_node_info
 @inverted_operation_enable_disable
+@get_replacement_parameter
 def make_node(
     *,
     graph_node: gs.Node,
@@ -95,6 +99,20 @@ def make_node(
         'dtype': dtype,
     }
 
+    # Param replacement - OP replacement
+    op_rep_params = kwargs.get('op_rep_params', [])
+    for op_rep_param in op_rep_params:
+        if op_rep_param['param_target'] == 'op':
+            new_shape = op_rep_param.get('new_shape', None)
+
+    # Pre-process transpose
+    input_tensor = pre_process_transpose(
+        value_before_transpose=input_tensor,
+        param_target='inputs',
+        param_name=graph_node.inputs[0].name,
+        **kwargs,
+    )
+
     # Generation of TF OP
     # https://github.com/onnx/onnx/blob/main/docs/Changelog.md#unsqueeze-13
     """
@@ -116,6 +134,14 @@ def make_node(
             name=graph_node.name,
         )
 
+    # Post-process transpose
+    tf_layers_dict[graph_node_output.name]['tf_node'] = post_process_transpose(
+        value_before_transpose=tf_layers_dict[graph_node_output.name]['tf_node'],
+        param_target='outputs',
+        param_name=graph_node.outputs[0].name,
+        **kwargs,
+    )
+
     # Generation of Debug Info
     tf_layers_dict[graph_node_output.name]['tf_node_info'] = \
         make_tf_node_info(
