@@ -8,6 +8,7 @@ import numpy as np
 np.random.seed(0)
 import tensorflow as tf
 from tensorflow.keras.layers import Lambda # type: ignore
+from tensorflow.python.keras.utils import conv_utils
 import onnx_graphsurgeon as gs
 from onnx2tf.utils.colors import Color
 from typing import Any, List, Optional, Union, Tuple
@@ -685,13 +686,102 @@ def broadcast_validity_check(
     return result
 
 
+def pre_explicit_broadcast(
+    *,
+    input_tensor_1: Any,
+    input_tensor_2: Any,
+) -> Tuple[Any, Any]:
+    """Shrink a tensor whose input_tensor_1 and input_tensor_2
+    have the same rank and all but one dimension is 1.
+
+    Parameters
+    ----------
+    input_tensor_1: Any
+        gs.Variable or np.ndarray
+
+    input_tensor_2: Any
+        gs.Variable or np.ndarray
+
+    Returns
+    ----------
+    input_tensor_1: Any
+        gs.Variable or np.ndarray
+
+    input_tensor_2: Any
+        gs.Variable or np.ndarray
+    """
+    # e.g.1
+    # input:
+    #   input_tensor_1: [1,80,80,12]
+    #   input_tensor_2: [1,12,1,1]
+    # output:
+    #   input_tensor_1: [1,80,80,12]
+    #   input_tensor_2: [12]
+    #
+    # e.g.2
+    # input:
+    #   input_tensor_1: [1,2,3,4]
+    #   input_tensor_2: [1,3,1,1]
+    # output:
+    #   input_tensor_1: [1,2,3,4]
+    #   input_tensor_2: [3,1]
+    if input_tensor_1.shape is not None \
+        and input_tensor_2.shape is not None \
+        and None not in input_tensor_1.shape \
+        and None not in input_tensor_2.shape \
+        and len(input_tensor_1.shape) == len(input_tensor_2.shape):
+
+        input_tensor_1_shape = input_tensor_1.shape
+        squeezed_input_tensor_1_shape = [idx for idx in input_tensor_1_shape if idx != 1]
+        squeezed_input_tensor_1_shape_rank = len(squeezed_input_tensor_1_shape)
+        input_tensor_2_shape = input_tensor_2.shape
+        if squeezed_input_tensor_1_shape_rank == 1 \
+            and squeezed_input_tensor_1_shape[0] in input_tensor_2_shape:
+            input_tensor_1 = tf.squeeze(input_tensor_1)
+            reversed_input_tensor_2_shape = []
+            if isinstance(input_tensor_2_shape, list):
+                reversed_input_tensor_2_shape = input_tensor_2_shape.reverse()
+            elif isinstance(input_tensor_2_shape, np.ndarray):
+                reversed_input_tensor_2_shape = input_tensor_2_shape[::-1].tolist()
+            elif isinstance(input_tensor_2_shape, tf.TensorShape):
+                reversed_input_tensor_2_shape = list(input_tensor_2_shape[::-1])
+            expand_count = reversed_input_tensor_2_shape.index(squeezed_input_tensor_1_shape[0])
+            for _ in range(expand_count):
+                input_tensor_1 = tf.expand_dims(
+                    input=input_tensor_1,
+                    axis=-1,
+                )
+        else:
+            input_tensor_2_shape = input_tensor_2.shape
+            squeezed_input_tensor_2_shape = [idx for idx in input_tensor_2_shape if idx != 1]
+            squeezed_input_tensor_2_shape_rank = len(squeezed_input_tensor_2_shape)
+            input_tensor_1_shape = input_tensor_1.shape
+            if squeezed_input_tensor_2_shape_rank == 1 \
+                and squeezed_input_tensor_2_shape[0] in input_tensor_1_shape:
+                input_tensor_2 = tf.squeeze(input_tensor_2)
+                reversed_input_tensor_1_shape = []
+                if isinstance(input_tensor_1_shape, list):
+                    reversed_input_tensor_1_shape = input_tensor_1_shape.reverse()
+                elif isinstance(input_tensor_1_shape, np.ndarray):
+                    reversed_input_tensor_1_shape = input_tensor_1_shape[::-1].tolist()
+                elif isinstance(input_tensor_1_shape, tf.TensorShape):
+                    reversed_input_tensor_1_shape = list(input_tensor_1_shape[::-1])
+                expand_count = reversed_input_tensor_1_shape.index(squeezed_input_tensor_2_shape[0])
+                for _ in range(expand_count):
+                    input_tensor_2 = tf.expand_dims(
+                        input=input_tensor_2,
+                        axis=-1,
+                    )
+    return input_tensor_1, input_tensor_2
+
+
 def explicit_broadcast(
     *,
     const_or_var_1: Any,
     const_or_var_2: Any,
     graph_node: Optional[gs.Node] = None,
     tf_layers_dict: dict = None,
-):
+) -> Tuple[Any, Any]:
     """Of the two tensors in the argument, the one with the lower dimensionality
     is broadcast to match the one with the higher dimensionality.
 
@@ -705,10 +795,10 @@ def explicit_broadcast(
 
     Returns
     ----------
-    const_or_var_1:
+    const_or_var_1: Any
         gs.Variable or np.ndarray
 
-    const_or_var_2
+    const_or_var_2: Any
         gs.Variable or np.ndarray
     """
     graph_node_input_name1 = None
@@ -2106,3 +2196,18 @@ def shape_unmatched_special_avoidance_workaround(
         input_tensor_2 = values[1]
 
     return input_tensor_1, input_tensor_2
+
+def calc_output_shape_conv_transpose(input_shape, kernel, pad_mode, output_padding, stride, dilation):
+    out_height = conv_utils.deconv_output_length(input_shape[0],
+                                                 kernel[0],
+                                                 padding=pad_mode.lower(),
+                                                 output_padding=output_padding[0],
+                                                 stride=stride[0],
+                                                 dilation=dilation[0])
+    out_width = conv_utils.deconv_output_length(input_shape[1],
+                                                kernel[1],
+                                                padding=pad_mode.lower(),
+                                                output_padding=output_padding[1],
+                                                stride=stride[1],
+                                                dilation=dilation[1])
+    return [out_height, out_width]
